package extmedias

import (
	"database/sql"
	"fmt"
	"os"
	"testing"

	_ "github.com/mattes/migrate/driver/postgres"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/sqly"

	"github.com/jmoiron/sqlx"
)

var db *sqlx.DB
var pgdsn string

func init() {
	var err error

	pgdsn = os.Getenv("POSTGRES_DSN")
	db, err = sqlx.Connect("postgres", pgdsn)

	if err != nil {
		fmt.Printf("Unavailable PG tests:\n    %v\n", err)
		os.Exit(1)
	}
}

func TestAddExternalMedias(t *testing.T) {
	sqly.RunWithLastestMigration(db, pgdsn, t, func(db *sqlx.DB, t *testing.T) {
		media := &Media{
			Type:     "movie",
			Source:   "trakttv",
			Category: "trending",
			IDs:      []string{"1", "2", "3"},
		}

		// Add it
		if err := media.Upsert(db); err != nil {
			t.Fatalf("failed to add external media: %q", err)
		}

		// Update the IDs
		media.IDs = []string{"1", "2", "3", "4"}
		if err := media.Upsert(db); err != nil {
			t.Fatalf("failed to update the external media: %q", err)
		}

		// Find it
		m, err := Get(db, media.Type, media.Source, media.Category)
		if err != nil {
			t.Fatalf("failed get the external media: %q", err)
		}

		// Small, almost useless check
		if len(m.IDs) != 4 {
			t.Fatalf("the media should have 4 ids, only %d found", len(m.IDs))
		}

		// Delete it
		if err := media.Delete(db); err != nil {
			t.Fatalf("failed to delete the external media: %q", err)
		}

		// Search it and expect that it's not found
		m, err = Get(db, media.Type, media.Source, media.Category)
		if err == nil {
			t.Fatal("there should be an error, was the external media deleted ?")
		}
		if err != sql.ErrNoRows {
			t.Fatalf("unexpected error: %q", err)
		}
	})
}
