package movies

import (
	"database/sql"
	"fmt"
	"os"
	"testing"

	"github.com/Sirupsen/logrus"
	"github.com/jmoiron/sqlx"
	_ "github.com/lib/pq"
	_ "github.com/mattes/migrate/driver/postgres"
	"github.com/odwrtw/polochon/lib"
	"github.com/odwrtw/polochon/modules/mock"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/config"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/sqly"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/web"
)

var db *sqlx.DB
var pgdsn string

func init() {
	var err error

	pgdsn = os.Getenv("POSTGRES_DSN")
	db, err = sqlx.Connect("postgres", pgdsn)

	if err != nil {
		fmt.Printf("Unavailable PG tests:\n    %v\n", err)
		os.Exit(1)
	}
}

func TestIntegrate(t *testing.T) {
	sqly.RunWithLastestMigration(db, pgdsn, t, func(db *sqlx.DB, t *testing.T) {
		log := logrus.NewEntry(logrus.New())
		env := web.NewEnv(web.EnvParams{
			Database: db,
			// Auth:     authorizer,
			Log: log,
			Config: &config.Config{
				PublicDir: "/tmp",
			},
		})
		detailer, _ := mock.NewDetailer(nil)
		polochonConfig := polochon.MovieConfig{
			Detailers: []polochon.Detailer{
				detailer,
			},
		}
		movie := Movie{
			Movie: polochon.Movie{
				MovieConfig: polochonConfig,
				ImdbID:      "tt12345",
				Genres:      []string{},
			},
		}

		err := movie.GetDetails(env, false)
		if err != nil {
			t.Fatal(err)
		}

		// Get it
		movie = Movie{
			Movie: polochon.Movie{
				MovieConfig: polochonConfig,
				ImdbID:      "tt12345",
			},
		}
		err = movie.Get(env)
		if err != nil {
			t.Fatal(err)
		}
		if movie.Title != fmt.Sprintf("Movie %s", movie.ImdbID) {
			t.Fatalf("Unexpected movie's title: %s", movie.Title)
		}

		// Delete it
		err = movie.Delete(db)
		if err != nil {
			t.Fatal(err)
		}

		// Get it again
		err = movie.Get(env)
		if err != sql.ErrNoRows {
			t.Fatalf("Unexpected error: %q", err)
		}
	})
}
