import React from 'react'

import { DropdownButton, MenuItem } from 'react-bootstrap'

export default class TorrentsButton extends React.Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }
  handleClick(e, url) {
    e.preventDefault();
    this.props.addTorrent(url);
  }
  render() {
    const entries = buildMenuItems(this.props.torrents);
    return (
      <DropdownButton className="btn btn-default btn-sm" title="Torrents" id="download-torrents-button" dropup>
        {entries.map(function(e, index) {
          switch (e.type) {
            case 'header':
              return (
                <MenuItem key={index} className="text-warning" header>
                  {e.value}
                </MenuItem>
              );
            case 'divider':
              return (
                <MenuItem key={index} divider></MenuItem>
              );
            case 'entry':
              return (
                <MenuItem key={index} href={e.url} onClick={(event) => this.handleClick(event, e.url)}>
                  {e.quality}
                </MenuItem>
              );
          }
        }, this)}
      </DropdownButton>
    );
  }
}

function buildMenuItems(torrents) {
  // Organise by source
  let sources = {}
  for (let torrent of torrents) {
    if (!sources[torrent.source]) {
      sources[torrent.source] = [];
    }
    sources[torrent.source].push(torrent);
  }

  // Build the array of entries
  let entries = [];
  let sourceNames = Object.keys(sources);
  let dividerCount = sourceNames.length - 1;
  for (let source of sourceNames) {
    // Push the title
    entries.push({
      type: "header",
      value: source,
    });

    // Push the torrents
    for (let torrent of sources[source]) {
      entries.push({
        type: "entry",
        quality: torrent.quality,
        url: torrent.url,
      });
    }

    // Push the divider
    if (dividerCount > 0) {
      dividerCount--;
      entries.push({ type: "divider" });
    }
  }

  return entries;
}
