import React from 'react'

import ListDetails from '../list/details'
import ListPosters from '../list/posters'
import Loader from '../loader/loader'
import ShowButtons from './listButtons'

export default class ShowList extends React.Component {
  componentWillMount() {
    if (this.props.showsUrl) {
      this.props.fetchShows(this.props.showsUrl);
    } else if (this.props.params && this.props.params.search != "") {
      this.props.searchShows({
        key: this.props.params.search
      });
    }
  }
  componentWillUpdate(nextProps, nextState) {
    if (!nextProps.params || nextProps.params.search === "") {
      return
    }
    if (this.props.params.search === nextProps.params.search) {
      return
    }
    this.props.searchShows({
      key: nextProps.params.search
    });
  }
  render() {
    const shows = this.props.showStore.shows;
    const selectedShowId = this.props.showStore.selectedImdbId;
    let index = shows.map((el) => el.imdb_id).indexOf(selectedShowId);
    if (index === -1) {
      index = 0;
    }
    const selectedShow = shows[index];

    // Loading
    if (this.props.showStore.loading) {
      return (<Loader />);
    }

    return (
      <div className="row" id="container">
        <ListPosters
          data={shows}
          formModel="showStore"
          controlModel="showStore.filter"
          controlPlaceHolder="Filter shows..."
          selectedImdbId={selectedShowId}
          filter={this.props.showStore.filter}
          perPage={this.props.showStore.perPage}
          onClick={this.props.selectShow}
        />
        {selectedShow &&
          <ListDetails data={selectedShow} >
            <ShowButtons
              show={selectedShow}
              deleteFromWishlist={this.props.deleteShowFromWishlist}
              addToWishlist={this.props.addShowToWishlist}
            />
          </ListDetails>
        }
      </div>
    );
  }
}
